==> 0.2.0.tar.gz: lib/witsystem_device_list_widget.dart <==
library witsystem_device_manage;

import 'package:flutter/services.dart';
import 'package:flutter_easyloading/flutter_easyloading.dart';
import 'package:witsystem_device_manage/generated/l10n.dart';
import 'package:flutter/material.dart';
import 'package:witsystem_device_manage/pages/home/add/AddDevice.dart';
import 'package:witsystem_device_manage/pages/home/slock/SlcokHome.dart';
import 'package:witsystem_device_plugin/device/DeviceManage.dart';
import 'package:witsystem_device_plugin/device/Unlock.dart';
import 'package:witsystem_device_manage/assets/icons/WitsIcon.dart';

class WitsystemDeviceListWidget extends StatefulWidget {
  const WitsystemDeviceListWidget({Key? key}) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return DeviceListState();
  }
}

class DeviceListState extends State<WitsystemDeviceListWidget>
    with SingleTickerProviderStateMixin {
  List deviceList = [];
  Animation<double>? _doubleAnim;
  AnimationController? _animationController;

  @override
  void initState() {
    super.initState();
    init();
  }

  init() async {
    var list = await DeviceManage.instance.deviceList();
    deviceList.clear();
    deviceList.addAll(list);
    setState(() {});
  }

  ///初始化心跳动画 暂时未使用
  initAnimation() {
    _animationController =
        AnimationController(vsync: this, duration: const Duration(seconds: 1))
          ..forward();
    _doubleAnim = Tween(begin: 0.0, end: 50.0).animate(_animationController!)
      ..addListener(() {
        setState(() {});
      })
      ..addStatusListener((status) {
        if (status == AnimationStatus.completed) {
          _animationController?.reverse();
        } else if (status == AnimationStatus.dismissed) {
          _animationController?.forward();
        }
      });
  }

  ///刷新设备信息

  ///区分不同类型显示不同的item
  Widget _deviceType(Map<String, dynamic> device) {
    switch (device['device']['type']) {
      case "Slock":
        return _slcokWidget(device);

      case "Ammet":
        return _ammetWidget(device);

      case "Relay":
        return _relayWidget(device);

      case "Water":
        return _waterWidget(device);

      default:
        return _defaultWidget(device);
    }
  }

  ///门锁
  Widget _slcokWidget(Map<String, dynamic> device) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Icon(
          WitsIcon.mensuo,
          color: (device['device']['onLine'] ? Colors.green : Colors.red),
          size: 40,
        ),
        GestureDetector(
          child: const Padding(
            padding: EdgeInsets.all(10),
            child: Icon(
              WitsIcon.open,
              color: Colors.red,
              size: 20,
            ),
          ),
          onTap: () async {
            try {
              EasyLoading.show(
                  status: S.of(context).device_openLoading,
                  maskType: EasyLoadingMaskType.clear);
              await Unlock.instance.bleUnlock(device['device']['deviceId']);
              EasyLoading.showSuccess(S.of(context).device_openSuccess);
            } on PlatformException catch (e) {
              EasyLoading.showError(
                  S.of(context).device_openFail(e.message.toString()));
            }
          },
        )
      ],
    );
  }

  ///电表
  Widget _ammetWidget(Map<String, dynamic> device) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Icon(
          WitsIcon.dianbiao,
          color: (device['device']['onLine'] ? Colors.green : Colors.red),
          size: 40,
        ),
        Text("${device['device']['devicesAmmet']['balance']}",
            style: const TextStyle(color: Colors.white, fontSize: 12))
      ],
    );
  }

  ///中继
  Widget _relayWidget(Map<String, dynamic> device) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Icon(
          WitsIcon.luyouqi,
          color: (device['device']['onLine'] ? Colors.green : Colors.red),
          size: 40,
        ),
        const Icon(WitsIcon.xinhao)
      ],
    );
  }

  ///水表
  Widget _waterWidget(Map<String, dynamic> device) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Icon(
          WitsIcon.shuibiao,
          color: (device['device']['onLine'] ? Colors.green : Colors.red),
          size: 40,
        ),
        Text("${device['device']['devicesWater']['balance']}",
            style: const TextStyle(color: Colors.white))
      ],
    );
  }

  ///默认
  Widget _defaultWidget(Map<String, dynamic> device) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Icon(
          WitsIcon.shebei,
          color: (device['device']['onLine'] ? Colors.green : Colors.red),
          size: 40,
        ),
        const Text("...", style: TextStyle(color: Colors.white))
      ],
    );
  }

  ///点击添加设备
  _addDevice() {
    Navigator.of(context).push(MaterialPageRoute(builder: (context) {
      return const AddDeviceWidget();
    }));
  }

  @override
  void dispose() {
    _animationController?.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
        color: Theme.of(context).primaryColor,
        padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
        child: RefreshIndicator(
            onRefresh: () {
              EasyLoading.showToast("敬请期待");
              init();
              return Future.value();
            },
            child: AnimatedCrossFade(
                duration: const Duration(milliseconds: 300),
                crossFadeState: deviceList.isEmpty
                    ? CrossFadeState.showFirst
                    : CrossFadeState.showSecond,
                firstChild: SizedBox(
                  height: MediaQuery.of(context).size.height - 120,
                  width: MediaQuery.of(context).size.width,
                  child: ListView(children: [
                    Container(
                        height: MediaQuery.of(context).size.height - 120,
                        width: double.infinity,
                        decoration: BoxDecoration(
                          color: const Color(0x00000000),
                          borderRadius: //设置四周圆角 角度
                              const BorderRadius.all(Radius.circular(6.0)),
                          border: Border.all(
                              width: 1, color: Colors.white10), //设置四周边框
                        ),
                        child: InkWell(
                            onTap: _addDevice,
                            child: Column(
                              mainAxisSize: MainAxisSize.min,
                              mainAxisAlignment: MainAxisAlignment.center,
                              children: [
                                const Padding(
                                    padding: EdgeInsets.fromLTRB(0, 0, 0, 10),
                                    child: Icon(WitsIcon.jiahao,
                                        color: Colors.white, size: 50)),
                                Text(S.of(context).device_clickAddDevice,
                                    style: const TextStyle(color: Colors.white))
                              ],
                            )))
                  ]),
                ),
                secondChild: SizedBox(
                  height: MediaQuery.of(context).size.height,
                  width: MediaQuery.of(context).size.width,
                  child: GridView.builder(
                      physics: const AlwaysScrollableScrollPhysics(),
                      gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
                          crossAxisCount:
                              (MediaQuery.of(context).size.width ~/ 180),
                          crossAxisSpacing: 10,
                          mainAxisSpacing: 10,
                          childAspectRatio: 1.5),
                      itemCount: deviceList.isNotEmpty
                          ? deviceList.length + 1
                          : 0, //加1是为了增加添加选项
                      itemBuilder: (context, index) {
                        return deviceList.length != index
                            ? GestureDetector(
                                onTap: () {
                                  Navigator.of(context).push(MaterialPageRoute(
                                      builder: (BuildContext context) {
                                    return SlcokHome(
                                        deviceId: deviceList[index]['device']
                                            ['deviceId'],
                                        deviceName: deviceList[index]['device']
                                            ['deviceName']);
                                  }));
                                },
                                child: Container(
                                  decoration: BoxDecoration(
                                    color: Theme.of(context).primaryColorLight,
                                    borderRadius: const BorderRadius.all(
                                        Radius.circular(6.0)),
                                    //设置四周圆角 角度
                                    border: Border.all(
                                        width: 1,
                                        color: Colors.white10), //设置四周边框
                                  ),
                                  padding:
                                      const EdgeInsets.fromLTRB(5, 5, 5, 15),
                                  child: Column(
                                    mainAxisAlignment:
                                        MainAxisAlignment.spaceBetween,
                                    children: [
                                      // Image.asset("images/t3.png",package: "witsystem_theme_a"),
                                      Row(
                                        mainAxisAlignment:
                                            MainAxisAlignment.spaceBetween,
                                        children: [
                                          Expanded(
                                            flex: 1,
                                            child: Text(
                                                "${deviceList[index]['deviceName']}",
                                                maxLines: 1,
                                                overflow: TextOverflow.ellipsis,
                                                style: const TextStyle(
                                                  color: Colors.white,
                                                  fontSize: 12,
                                                )),
                                          ),
                                          Text(
                                              deviceList[index]['device']
                                                      ['onLine']
                                                  ? S.of(context).device_onLine
                                                  : S
                                                      .of(context)
                                                      .device_offLine,
                                              style: const TextStyle(
                                                  color: Colors.white,
                                                  fontSize: 12)),
                                        ],
                                      ),
                                      _deviceType(deviceList[index]),
                                    ],
                                  ),
                                ),
                              )
                            : Container(
                                decoration: BoxDecoration(
                                  color: Theme.of(context).primaryColorLight,
                                  borderRadius: //设置四周圆角 角度
                                      const BorderRadius.all(
                                          Radius.circular(6.0)),
                                  border: Border.all(
                                      width: 1, color: Colors.white10), //设置四周边框
                                ),
                                child: InkWell(
                                    onTap: _addDevice,
                                    child: const Icon(WitsIcon.jiahao,
                                        color: Colors.white, size: 35)),
                              );
                      }),
                ))));
  }
}

==> 0.2.8.tar.gz: lib/witsystem_device_list_widget.dart <==
library witsystem_device_manage;

import 'package:flutter/services.dart';
import 'package:flutter_easyloading/flutter_easyloading.dart';
import 'package:witsystem_core/config/VibrateConfig.dart';
import 'package:witsystem_core/permission/WitsPermission.dart';
import 'package:witsystem_device_manage/generated/l10n.dart';
import 'package:flutter/material.dart';
import 'package:witsystem_device_manage/pages/home/add/AddDevice.dart';
import 'package:witsystem_device_manage/pages/home/slock/SlcokHome.dart';
import 'package:witsystem_device_plugin/device/DeviceManage.dart';
import 'package:witsystem_device_plugin/device/Unlock.dart';
import 'package:witsystem_device_manage/assets/icons/WitsIcon.dart';

class WitsystemDeviceListWidget extends StatefulWidget {
  const WitsystemDeviceListWidget({Key? key}) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return DeviceListState();
  }
}

class DeviceListState extends State<WitsystemDeviceListWidget> {
  List deviceList = [];

  @override
  void initState() {
    super.initState();
    WitsPermission.blePermission();
    init();
    _deviceChange();



  }

  ///监听设备的信息变化
  _deviceChange() {
    DeviceManage().addDeviceChangeObserver((data) {
      init();
    });
  }

  init() async {
    var list = await DeviceManage.instance.deviceList();
    deviceList.clear();
    deviceList.addAll(list);
    setState(() {});
  }

  ///区分不同类型显示不同的item
  Widget _deviceType(Map<String, dynamic> device) {
    switch (device['device']['type']) {
      case "Slock":
        return _slcokWidget(device);

      case "Ammet":
        return _ammetWidget(device);

      case "Relay":
        return _relayWidget(device);

      case "Water":
        return _waterWidget(device);

      default:
        return _defaultWidget(device);
    }
  }

  ///门锁
  Widget _slcokWidget(Map<String, dynamic> device) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Icon(
          WitsIcon.mensuo,
          color: (device['device']['onLine'] ? Colors.green : Colors.red),
          size: 40,
        ),
        GestureDetector(
          child: const Padding(
            padding: EdgeInsets.all(10),
            child: Icon(
              WitsIcon.open,
              color: Colors.red,
              size: 20,
            ),
          ),
          onTap: () async {
            try {
              if (!await WitsPermission.blePermission()) return;
              EasyLoading.show(
                  status: S.of(context).device_openLoading,
                  maskType: EasyLoadingMaskType.clear);
              await Unlock.instance.bleUnlock(device['device']['deviceId'],isVibrate: VibrateConfig().unlockVibrate);
              EasyLoading.showSuccess(S.of(context).device_openSuccess);
            } on PlatformException catch (e) {
              EasyLoading.showError(
                  S.of(context).device_openFail(e.message.toString()));
            }
          },
        )
      ],
    );
  }

  ///电表
  Widget _ammetWidget(Map<String, dynamic> device) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Icon(
          WitsIcon.dianbiao,
          color: (device['device']['onLine'] ? Colors.green : Colors.red),
          size: 40,
        ),
        Text("${device['device']['devicesAmmet']['balance']}",
            style: const TextStyle(color: Colors.white, fontSize: 12))
      ],
    );
  }

  ///中继
  Widget _relayWidget(Map<String, dynamic> device) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Icon(
          WitsIcon.luyouqi,
          color: (device['device']['onLine'] ? Colors.green : Colors.red),
          size: 40,
        ),
        const Icon(WitsIcon.xinhao)
      ],
    );
  }

  ///水表
  Widget _waterWidget(Map<String, dynamic> device) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Icon(
          WitsIcon.shuibiao,
          color: (device['device']['onLine'] ? Colors.green : Colors.red),
          size: 40,
        ),
        Text("${device['device']['devicesWater']['balance']}",
            style: const TextStyle(color: Colors.white))
      ],
    );
  }

  ///默认
  Widget _defaultWidget(Map<String, dynamic> device) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Icon(
          WitsIcon.shebei,
          color: (device['device']['onLine'] ? Colors.green : Colors.red),
          size: 40,
        ),
        const Text("...", style: TextStyle(color: Colors.white))
      ],
    );
  }

  ///点击添加设备
  _addDevice() {
    Navigator.of(context).push(MaterialPageRoute(builder: (context) {
      return const AddDeviceWidget();
    }));
  }


  @override
  void dispose() {
    DeviceManage().removeDeviceChangeObserver();//移除所有的设备观察者
    super.dispose();
  }
  @override
  Widget build(BuildContext context) {
    return Container(
        color: Theme.of(context).primaryColor,
        padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
        child: RefreshIndicator(
            onRefresh: () async {
              await DeviceManage().refurbishAllDevice();
              await init();
              return Future.value();
            },
            child: AnimatedCrossFade(
                duration: Duration(milliseconds: deviceList.isEmpty ? 50 : 300),
                crossFadeState: deviceList.isEmpty
                    ? CrossFadeState.showFirst
                    : CrossFadeState.showSecond,
                firstChild: SizedBox(
                  height: MediaQuery.of(context).size.height - 120,
                  width: MediaQuery.of(context).size.width,
                  child: ListView(children: [
                    Container(
                        height: MediaQuery.of(context).size.height - 120,
                        width: double.infinity,
                        decoration: BoxDecoration(
                          color: const Color(0x00000000),
                          borderRadius: //设置四周圆角 角度
                              const BorderRadius.all(Radius.circular(6.0)),
                          border: Border.all(
                              width: 1, color: Colors.white10), //设置四周边框
                        ),
                        child: InkWell(
                            onTap: _addDevice,
                            child: Column(
                              mainAxisSize: MainAxisSize.min,
                              mainAxisAlignment: MainAxisAlignment.center,
                              children: [
                                const Padding(
                                    padding: EdgeInsets.fromLTRB(0, 0, 0, 10),
                                    child: Icon(WitsIcon.jiahao,
                                        color: Colors.white, size: 50)),
                                Text(S.of(context).device_clickAddDevice,
                                    style: const TextStyle(color: Colors.white))
                              ],
                            )))
                  ]),
                ),
                secondChild: SizedBox(
                  height: MediaQuery.of(context).size.height,
                  width: MediaQuery.of(context).size.width,
                  child: GridView.builder(
                      physics: const AlwaysScrollableScrollPhysics(),
                      gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
                          crossAxisCount:
                              (MediaQuery.of(context).size.width ~/ 180),
                          crossAxisSpacing: 10,
                          mainAxisSpacing: 10,
                          childAspectRatio: 1.5),
                      itemCount: deviceList.isNotEmpty
                          ? deviceList.length + 1
                          : 0, //加1是为了增加添加选项
                      itemBuilder: (context, index) {
                        return deviceList.length != index
                            ? GestureDetector(
                                onTap: () {
                                  Navigator.of(context).push(MaterialPageRoute(
                                      settings: const RouteSettings(
                                          name: "deviceIndex"), //跳转的时候给跳转到的页面命名
                                      builder: (BuildContext context) {
                                        return SlcokHome(
                                            deviceId: deviceList[index]
                                                ['device']['deviceId'],
                                            deviceName: deviceList[index]['deviceName']);
                                      }));
                                },
                                child: Container(
                                  decoration: BoxDecoration(
                                    color: Theme.of(context).primaryColorLight,
                                    borderRadius: const BorderRadius.all(
                                        Radius.circular(6.0)),
                                    //设置四周圆角 角度
                                    border: Border.all(
                                        width: 1,
                                        color: Colors.white10), //设置四周边框
                                  ),
                                  padding:
                                      const EdgeInsets.fromLTRB(5, 5, 5, 15),
                                  child: Column(
                                    mainAxisAlignment:
                                        MainAxisAlignment.spaceBetween,
                                    children: [
                                      // Image.asset("images/t3.png",package: "witsystem_theme_a"),
                                      Row(
                                        mainAxisAlignment:
                                            MainAxisAlignment.spaceBetween,
                                        children: [
                                          Expanded(
                                            flex: 1,
                                            child: Text(
                                                "${deviceList[index]['deviceName']}",
                                                maxLines: 1,
                                                overflow: TextOverflow.ellipsis,
                                                style: const TextStyle(
                                                  color: Colors.white,
                                                  fontSize: 12,
                                                )),
                                          ),
                                          Text(
                                              deviceList[index]['device']
                                                      ['onLine']
                                                  ? S.of(context).device_onLine
                                                  : S
                                                      .of(context)
                                                      .device_offLine,
                                              style: const TextStyle(
                                                  color: Colors.white,
                                                  fontSize: 12)),
                                        ],
                                      ),
                                      _deviceType(deviceList[index]),
                                    ],
                                  ),
                                ),
                              )
                            : Container(
                                decoration: BoxDecoration(
                                  color: Theme.of(context).primaryColorLight,
                                  borderRadius: //设置四周圆角 角度
                                      const BorderRadius.all(
                                          Radius.circular(6.0)),
                                  border: Border.all(
                                      width: 1, color: Colors.white10), //设置四周边框
                                ),
                                child: InkWell(
                                    onTap: _addDevice,
                                    child: const Icon(WitsIcon.jiahao,
                                        color: Colors.white, size: 35)),
                              );
                      }),
                ))));
  }
}
